==> haskell-docopt-0.7.0.5-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-docopt.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: docopt
version: 0.7.0.5
id: docopt-0.7.0.5-IMthXmbrRebFax908yxb4p
key: docopt-0.7.0.5-IMthXmbrRebFax908yxb4p
license: MIT
copyright: (c) 2013-2015 Ryan Artecona
maintainer: ryanartecona@gmail.com
homepage: https://github.com/docopt/docopt.hs
synopsis: A command-line interface parser that will make you smile
description:
    Docopt parses command-line interface usage text that adheres to a familiar syntax, and from it builds a command-line argument parser that will ensure your program is invoked correctly with the available options specified in the usage text. This allows the developer to write a usage text and get an argument parser for free.
category: Console
author: Ryan Artecona
exposed: True
indefinite: False
exposed-modules:
    System.Console.Docopt System.Console.Docopt.NoTH
hidden-modules: System.Console.Docopt.ApplicativeParsec
                System.Console.Docopt.ParseUtils System.Console.Docopt.Types
                System.Console.Docopt.UsageParse System.Console.Docopt.OptParse
                System.Console.Docopt.Public System.Console.Docopt.QQ
                System.Console.Docopt.QQ.Instances
abi: 4e52bf06d8c79dd3d21aed1354e1f067
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/docopt-0.7.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/docopt-0.7.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/docopt-0.7.0.5
hs-libraries: HSdocopt-0.7.0.5-IMthXmbrRebFax908yxb4p
depends:
    base-4.10.1.0 parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7
    containers-0.5.10.2 template-haskell-2.12.0.0
    th-lift-0.7.8-9WoT75e11sF5vCUkzmby5Q
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7=5b8a6db8c81629fde3a12212030372e3
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             th-lift-0.7.8-9WoT75e11sF5vCUkzmby5Q=45860d93836c2d823f47ee3c78d7c61c
haddock-interfaces: /usr/share/doc/haskell-docopt/html/docopt.haddock
haddock-html: /usr/share/doc/haskell-docopt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-docopt-0.7.0.5-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-docopt.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: docopt
version: 0.7.0.5
id: docopt-0.7.0.5-BK7DDO65EzE1riqOWl76YI
key: docopt-0.7.0.5-BK7DDO65EzE1riqOWl76YI
license: MIT
copyright: (c) 2013-2015 Ryan Artecona
maintainer: ryanartecona@gmail.com
homepage: https://github.com/docopt/docopt.hs
synopsis: A command-line interface parser that will make you smile
description:
    Docopt parses command-line interface usage text that adheres to a familiar syntax, and from it builds a command-line argument parser that will ensure your program is invoked correctly with the available options specified in the usage text. This allows the developer to write a usage text and get an argument parser for free.
category: Console
author: Ryan Artecona
exposed: True
indefinite: False
exposed-modules:
    System.Console.Docopt System.Console.Docopt.NoTH
hidden-modules: System.Console.Docopt.ApplicativeParsec
                System.Console.Docopt.ParseUtils System.Console.Docopt.Types
                System.Console.Docopt.UsageParse System.Console.Docopt.OptParse
                System.Console.Docopt.Public System.Console.Docopt.QQ
                System.Console.Docopt.QQ.Instances
abi: a1516c69853ee58b3a87b51f4056d488
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/docopt-0.7.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/docopt-0.7.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/docopt-0.7.0.5
hs-libraries: HSdocopt-0.7.0.5-BK7DDO65EzE1riqOWl76YI
depends:
    base-4.10.1.0 parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap
    containers-0.5.10.2 template-haskell-2.12.0.0
    th-lift-0.7.8-9WoT75e11sF5vCUkzmby5Q
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap=e5bced146b6517b43ed5d06001479bde
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             th-lift-0.7.8-9WoT75e11sF5vCUkzmby5Q=45860d93836c2d823f47ee3c78d7c61c
haddock-interfaces: /usr/share/doc/haskell-docopt/html/docopt.haddock
haddock-html: /usr/share/doc/haskell-docopt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
